@@ -97,7 +97,7 @@ fn convert_to_arg_access(context: &str, arg: Expr, as_proxy: bool, ignore: &[&st
                     let right_token = b.right.to_token_stream().to_string();
                     if left_token.trim().ends_with("\"") && left_token.trim().starts_with("\"") {
                         b.left = Box::new(syn::parse_str::<Expr>(&format!("String::from({})", b.left.to_token_stream().to_string().trim())).unwrap());
-                        b.right = Box::new(syn::parse_str::<Expr>(&format!("({}).into()", b.right.to_token_stream().to_string().trim())).unwrap());
+                        b.right = Box::new(syn::parse_str::<Expr>(&format!("{}.into()", b.right.to_token_stream().to_string().trim())).unwrap());
                     }
                 }
                 _ => {}
